Plugin: JS9Magnifier

### JS9 Magnifier

The Magnifier plugin displays a blocked image of the data in an area surrounding the mouse as it moves. The default magnification of four can be changed using command buttons on the magnifier window.

By default, regions are displayed in the magnifier at the current zoom. You can turn off region display by changing the value of the JS9.globalOpts.magnifierRegions property, either by using the Preferences plugin or, for site-wide configuration, by changing the value in the js9prefs.js file.